diff --git a/cfg_core.c b/cfg_core.c
index ac67b11..a76efdc 100644
--- a/cfg_core.c
+++ b/cfg_core.c
@@ -122,7 +122,8 @@ struct cfg_group_core default_core_cfg = {
 	L_ERR, /*!< corelog */
 	L_ERR, /*!< latency log */
 	0, /*!< latency limit db */
-	0 /*!< latency limit action */
+	0, /*!< latency limit action */
+	0 /*!< log assign actions (disabled by default) */
 };
 
 void	*core_cfg = &default_core_cfg;
@@ -322,5 +323,7 @@ cfg_def_t core_cfg_def[] = {
 		"limit is ms for alerting on time consuming db commands"},
 	{"latency_limit_action",		CFG_VAR_INT|CFG_ATOMIC,	0, 0, 0, 0,
 		"limit is ms for alerting on time consuming config actions"},
+	{"log_assign_actions", CFG_VAR_INT|CFG_ATOMIC,	0, 1, 0, 0,
+		"enable/disable logging of assign actions"},
 	{0, 0, 0, 0, 0, 0}
 };
diff --git a/cfg_core.h b/cfg_core.h
index 4bfbfbb..a5d84d0 100644
--- a/cfg_core.h
+++ b/cfg_core.h
@@ -114,6 +114,7 @@ struct cfg_group_core {
 	int latency_log; /*!< log level for latency limits messages */
 	int latency_limit_db; /*!< alert limit of running db commands */
 	int latency_limit_action; /*!< alert limit of running cfg actions */
+	int log_assign_actions; /* activate/deactivate log for assign actions */
 };
 
 extern struct cfg_group_core default_core_cfg;
diff --git a/lvalue.c b/lvalue.c
index a89cfce..d7f911c 100644
--- a/lvalue.c
+++ b/lvalue.c
@@ -35,7 +35,7 @@
 #include "lvalue.h"
 #include "dprint.h"
 #include "route.h"
-
+#include "cfg_core.h"
 
 
 /**
@@ -364,7 +364,46 @@ drop:
 	return EXPR_DROP;
 }
 
+int log_assign_action_avp(struct sip_msg* msg, struct lvalue* lv)
+{
+	int_str avp_val;
+	avp_t* avp;
+	avp_spec_t* avp_s = &lv->lv.avps;
+	DBG("$avp(%.*s)[%d]: ", avp_s->name.s.len, avp_s->name.s.s, avp_s->index);
+	avp = search_avp_by_index(avp_s->type, avp_s->name,
+				&avp_val, avp_s->index);
+	if (likely(avp)){
+		if (avp->flags & AVP_VAL_STR){
+			DBG("%.*s\n", avp_val.s.len, avp_val.s.s);
+		}else{
+			DBG("%d\n", avp_val.n);
+		}
+	}
+	return 0;
+}
 
+int log_assign_action_pvar(struct sip_msg* msg, struct lvalue* lv)
+{
+	pv_value_t value;
+	pv_spec_t* pvar = &lv->lv.pvs;
+	/* how I get the name of the pvar ?? */
+	str name = {"unknown", 7};
+
+	if(pv_get_spec_value(msg, pvar, &value)!=0)
+	{
+		ERR("can't get value\n");
+		return -1;
+	}
+	DBG("value.flags: %d\n", value.flags);
+	if(value.flags&(PV_VAL_NULL|PV_VAL_EMPTY|PV_VAL_NONE)){
+		DBG("$var(%.*s): $null\n", name.len, name.s);
+	}else if(value.flags&(PV_VAL_STR)){
+		DBG("$var(%.*s): %.*s\n", name.len, name.s, value.rs.len, value.rs.s);
+	}else if(value.flags&(PV_VAL_INT)){
+		DBG("$var(%.*s): %d\n", name.len, name.s, value.ri);
+	}
+	return 0;
+}
 
 /** eval rve and assign the result to lv
  * lv=eval(rve)
@@ -375,12 +414,12 @@ drop:
  * @param rve - rvalue expression
  * @return >= 0 on success (expr. bool value), -1 on error
  */
-int lval_assign(struct run_act_ctx* h, struct sip_msg* msg, 
+int lval_assign(struct run_act_ctx* h, struct sip_msg* msg,
 				struct lvalue* lv, struct rval_expr* rve)
 {
 	struct rvalue* rv;
 	int ret;
-	
+
 	ret=0;
 	rv=rval_expr_eval(h, msg, rve);
 	if (unlikely(rv==0)){
@@ -406,6 +445,22 @@ int lval_assign(struct run_act_ctx* h, struct sip_msg* msg,
 			rve->fpos.s_line, rve->fpos.s_col,
 			rve->fpos.e_line, rve->fpos.e_col);
 	}
+	else
+	{
+		if(cfg_get(core, core_cfg, log_assign_actions)>0)
+		{
+			switch(lv->type){
+				case LV_AVP:
+					log_assign_action_avp(msg, lv);
+					break;
+				case LV_PVAR:
+					log_assign_action_pvar(msg, lv);
+					break;
+				case LV_NONE:
+					break;
+			}
+		}
+	}
 	rval_destroy(rv);
 	return ret;
 error:
